Package convex.java

Class Convex

java.lang.Object
convex.java.Convex

public class Convex extends Object
This class represents a remote client connection to the Convex Network, which can connect to any peer server that supports the REST Client API, e.g. the one at 'https://convex.world' Although this class can be used concurrently from multiple threads, it is strongly recommended to avoid executing transactions that use the same the same Account from multiple threads because each transaction requires incrementing a "sequence number" that may become mismatched if concurrent transactions are submitted. Read-only actions (e.g. queries) do not have this limitation.