Package convex.java
package convex.java
-
ClassDescriptionException class for Convex client errorsThis class represents a remote client connection to the Convex Network, which can connect to any peer server that supports the REST Client API, e.g.Simple JSON tools